==> jc-1.4.0.tar.gz: java__5fcup/assoc.h <==
// public class java_cup.assoc

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a88977c1da20de5c java__5fcup_assoc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_assoc_H_
#define _JC_java__5fcup_assoc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java__5fcup_assoc$sub_refs	_jc_java__5fcup_assoc$sub_refs;
typedef struct _jc_java__5fcup_assoc$sub_nonrefs	_jc_java__5fcup_assoc$sub_nonrefs;
typedef struct _jc_java__5fcup_assoc$refs	_jc_java__5fcup_assoc$refs;
typedef struct _jc_java__5fcup_assoc$nonrefs	_jc_java__5fcup_assoc$nonrefs;
typedef struct _jc_java__5fcup_assoc$object	_jc_java__5fcup_assoc$object;

typedef struct _jc_java__5fcup_assoc$fields_struct	_jc_java__5fcup_assoc$fields_struct;
typedef const struct _jc_java__5fcup_assoc$vmethods	_jc_java__5fcup_assoc$vmethods;
typedef const struct _jc_java__5fcup_assoc$vtable	_jc_java__5fcup_assoc$vtable;
typedef const struct _jc_java__5fcup_assoc$vtype	_jc_java__5fcup_assoc$vtype;

// Class fields structure
struct _jc_java__5fcup_assoc$fields_struct {
	jint	left;
	jint	no__5fprec;
	jint	nonassoc;
	jint	right;
};
extern _jc_java__5fcup_assoc$fields_struct _jc_java__5fcup_assoc$class_fields;

// Constructors
extern void _jc_java__5fcup_assoc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_assoc$object *);

// Virtual methods structure
struct _jc_java__5fcup_assoc$vmethods {
};

// Vtable
struct _jc_java__5fcup_assoc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_assoc$vmethods	java__5fcup_assoc;
};

// Vtype
struct _jc_java__5fcup_assoc$vtype {
	_jc_type			type;
	_jc_java__5fcup_assoc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_assoc$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_assoc$refs {
    _jc_java__5fcup_assoc$sub_refs	java__5fcup_assoc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_assoc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_assoc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_assoc$sub_nonrefs	java__5fcup_assoc;
};

// Object instance structure
struct _jc_java__5fcup_assoc$object {
	_jc_java__5fcup_assoc$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_assoc$vtype	*vtype;
	_jc_java__5fcup_assoc$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_assoc$vtype _jc_java__5fcup_assoc$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_assoc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_assoc$class_object;

#endif	/* _JC_java__5fcup_assoc_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/assoc.h <==
// public class java_cup.assoc

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a88977c1da20de5c java__5fcup_assoc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_assoc_H_
#define _JC_java__5fcup_assoc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java__5fcup_assoc$sub_refs	_jc_java__5fcup_assoc$sub_refs;
typedef struct _jc_java__5fcup_assoc$sub_nonrefs	_jc_java__5fcup_assoc$sub_nonrefs;
typedef struct _jc_java__5fcup_assoc$refs	_jc_java__5fcup_assoc$refs;
typedef struct _jc_java__5fcup_assoc$nonrefs	_jc_java__5fcup_assoc$nonrefs;
typedef struct _jc_java__5fcup_assoc$object	_jc_java__5fcup_assoc$object;

typedef struct _jc_java__5fcup_assoc$fields_struct	_jc_java__5fcup_assoc$fields_struct;
typedef const struct _jc_java__5fcup_assoc$vmethods	_jc_java__5fcup_assoc$vmethods;
typedef const struct _jc_java__5fcup_assoc$vtable	_jc_java__5fcup_assoc$vtable;
typedef const struct _jc_java__5fcup_assoc$vtype	_jc_java__5fcup_assoc$vtype;

// Class fields structure
struct _jc_java__5fcup_assoc$fields_struct {
	jint	left;
	jint	no__5fprec;
	jint	nonassoc;
	jint	right;
};
extern _jc_java__5fcup_assoc$fields_struct _jc_java__5fcup_assoc$class_fields;

// Constructors
extern void _jc_java__5fcup_assoc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_assoc$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_assoc$vmethods {
};

// Vtable
struct _jc_java__5fcup_assoc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_assoc$vmethods	java__5fcup_assoc;
};

// Vtype
struct _jc_java__5fcup_assoc$vtype {
	_jc_type			type;
	_jc_java__5fcup_assoc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_assoc$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_assoc$refs {
    _jc_java__5fcup_assoc$sub_refs	java__5fcup_assoc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_assoc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_assoc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_assoc$sub_nonrefs	java__5fcup_assoc;
};

// Object instance structure
struct _jc_java__5fcup_assoc$object {
	_jc_java__5fcup_assoc$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_assoc$vtype	*vtype;
	_jc_java__5fcup_assoc$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_assoc$vtype _jc_java__5fcup_assoc$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_assoc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_assoc$class_object;

#endif	/* _JC_java__5fcup_assoc_H_ */
